@@ -3,13 +3,11 @@
 #
 #  (C) Paul Evans, 2020 -- leonerd@leonerd.org.uk
 
-package Object::Pad::MOP::Method;
+package Object::Pad::MOP::Method 0.37;
 
 use v5.14;
 use warnings;
 
-our $VERSION = '0.36';
-
 # This is an XS-implemented object type provided by Object::Pad itself
 require Object::Pad;
 
